@@ -45,15 +45,17 @@ default_config = {
 
 account_map = {
     'HireEz-OPS1': ['ops1', 'us-west-1'],
-    'Hiretaul Resold': ['Master', 'us-west-2'],
+    'HireEz-OPS2': ['ops2', 'us-west-2'],
+    'Hiretaul Resold': ['master', 'us-west-2'],
+    'Test': ['test', 'us-west-1'],
     'Stage': ['stage', 'us-west-1'],
-    'HireEz-PROD2': ['prod2', 'us-west-2'],
     'prod': ['prod', 'us-west-1'],
     'HireEz-TEST1': ['test1', 'us-west-1'],
+    'HireEz-TEST2': ['test2', 'us-west-2'],
     'HireEz-STAGE1': ['stage1', 'us-west-1'],
-    'Test': ['test', 'us-west-1'],
-    'HireEz-OPS2': ['ops2', 'us-west-2'],
-    'HireEz-PROD1': ['prod1', 'us-west-1']
+    'HireEz-STAGE2': ['stage2', 'us-west-2'],
+    'HireEz-PROD1': ['prod1', 'us-west-1'],
+    'HireEz-PROD2': ['prod2', 'us-west-2']
 }
 
 if not os.path.exists(AWS_CONFIG_DIR):
@@ -464,16 +466,17 @@ def _gen_config_file():
                 accessToken=accessToken,
                 accountId=accountId)
             if r1.get('ResponseMetadata').get('HTTPStatusCode') == 200:
-                n = 1
                 for role in r1.get('roleList'):
                     role = role.get('roleName')
-                    p_name = 'profile {}'.format(profile_name)
-                    if not re.match('^[A-Z].*', role):
-                        p_name = '{}{}'.format(p_name, role)
-                    if n == 1 and config.has_section(p_name):
+                    p_name = 'profile {}{}'.format(profile_name, role)
+                    if config.has_section(p_name):
                         config.remove_section(p_name)
-                    elif n > 1 and config.has_section(p_name):
-                        p_name = '{}{}'.format(p_name, role)
+                    #if not re.match('^[A-Z].*', role):
+                    #    p_name = '{}{}'.format(p_name, role)
+                    #if n == 1 and config.has_section(p_name):
+                    #    config.remove_section(p_name)
+                    #elif n > 1 and config.has_section(p_name):
+                    #    p_name = '{}{}'.format(p_name, role)
                     config.add_section(p_name)
                     config.set(p_name, 'sso_start_url', 'https://hireteammate.awsapps.com/start')
                     config.set(p_name, 'sso_region', 'us-west-2')
@@ -481,10 +484,21 @@ def _gen_config_file():
                     config.set(p_name, 'sso_role_name', role)
                     config.set(p_name, 'region', region)
                     config.set(p_name, 'output', 'json')
-                    n += 1
             else:
                 print('auth error, please check your aws sso config file')
                 return False
+        for i in account_map:
+            if config.has_section('profile {}_ADMIN'.format(account_map[i][0])):
+                s_name = 'profile {}'.format(account_map[i][0])
+                config._sections[s_name] = config._sections.pop('profile {}_ADMIN'.format(account_map[i][0]))
+            elif not re.match('.*[0-9]$', account_map[i][0]):
+                continue
+            else:
+                for section in config.sections():
+                    if section.startswith('profile {}'.format(account_map[i][0])) and section.find('_') != -1:
+                        config._sections[re.sub('_.*', '', section)] = config._sections.pop(section)
+
+
         _write_config(AWS_CONFIG_PATH, config)
     else:
         print('auth error, please check your aws sso config file')
